@@ -3,7 +3,8 @@ package Nitesi::Account::Password;
 use strict;
 use warnings;
 
-use Crypt::Password ();
+use Crypt::Password 0.23 ();
+use Data::SimplePassword;
 
 use base 'Nitesi::Object::Singleton';
 
@@ -58,6 +59,19 @@ sub password {
     return $password;
 }
 
+=head2 make_password
+
+Creates random password.
+
+=cut
+
+sub make_password {
+    my $self = shift;
+
+    $self->{generator} ||= Data::SimplePassword->new;
+    $self->{generator}->make_password;
+}
+
 =head1 AUTHOR
 
 Stefan Hornburg (Racke), <racke@linuxia.de>
